<?php
/* Customize Appearance Options */
if ( !function_exists( 'robin_customizeAppearance' ) ) {
	function robin_customizeAppearance( $wp_customize ) {

		/* Custom Text Area Control in Customizer */
		class robin_customTextAreaControl extends WP_Customize_Control {

			public $type = 'textarea';

			public function render_content() { ?>
				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<textarea rows="8" style="width: 100%; resize: none;" <?php esc_url( $this->link() ); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
				</label>
			<?php }

		}
		/* */

		/* Font Selector */
		class robin_font_selector extends WP_Customize_Control {

				public $type = 'select';

				public function render_content() { ?>

					<label>
						<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
						<span class="customize-control-description"><?php echo wp_kses_post( $this->description ); ?></span>
						<select <?php $this->link(); ?>>
	                    	<?php
							foreach ( robin_font_labels() as $key => $val ) {
								$add_underscore = str_replace( ' ', '_', $key ); ?>
								<option value="<?php echo esc_attr( $add_underscore ); ?>" <?php if( $this->value() == $add_underscore ) echo 'selected="selected"'; ?>><?php echo esc_attr( $key ); ?></option>
							<?php } ?>
						</select>
					</label>

				<?php }

		}
		/* */

		/* BRNHMBX Banner Placement */
		class robin_BannerPlacement extends WP_Customize_Control {

			public $type = 'select';

			public function render_content() { ?>

				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<div style="margin-bottom: 10px;"><em><?php echo esc_html( $this->description ); ?></em></div>
					<select <?php $this->link(); ?> style="width: 100%;">
						<option value="hidden" <?php if( $this->value() == 'hidden' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Hidden' ); ?></option>
						<option value="above-full-slider" <?php if( $this->value() == 'above-full-slider' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Above Slider' ); ?></option>
						<option value="below-cover-slider" <?php if( $this->value() == 'below-cover-slider' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Below Slider' ); ?></option>
						<option value="above-among-slider" <?php if( $this->value() == 'above-among-slider' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Above Slider (Among the Posts)' ); ?></option>
						<option value="below-among-slider" <?php if( $this->value() == 'below-among-slider' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Below Slider (Among the Posts)' ); ?></option>
						<option value="below-upper-widgets" <?php if( $this->value() == 'below-upper-widgets' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Below Upper Widgets' ); ?></option>
						<option value="after-first-post" <?php if( $this->value() == 'after-first-post' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'After First Post' ); ?></option>
						<option value="below-blog-posts" <?php if( $this->value() == 'below-blog-posts' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Below Blog Posts' ); ?></option>
						<option value="below-home-widgets" <?php if( $this->value() == 'below-home-widgets' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Below Home Widgets' ); ?></option>
						<option value="above-post" <?php if( $this->value() == 'above-post' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Post Pages (Above the Post)' ); ?></option>
						<option value="below-post" <?php if( $this->value() == 'below-post' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Post Pages (Below the Post)' ); ?></option>
						<option value="below-post-comments" <?php if( $this->value() == 'below-post-comments' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Post Pages (Below Post Comments)' ); ?></option>
						<option value="above-page" <?php if( $this->value() == 'above-page' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Pages (Above the Page)' ); ?></option>
						<option value="below-page" <?php if( $this->value() == 'below-page' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Pages (Below the Page)' ); ?></option>
						<option value="below-page-comments" <?php if( $this->value() == 'below-page-comments' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Pages (Below Page Comments)' ); ?></option>
					</select>
				</label>

			<?php }

		}
		/* */

		/* Sanitizers */
		function robin_get_font_list() {
			$font_list = array();
			foreach ( robin_font_labels() as $key => $val ) {
				$add_underscore = str_replace( ' ', '_', $key );
				$font_list[] = esc_attr( $add_underscore );
			}
			return $font_list;
		}

		function robin_sanitize_select( $input ) {
			$current_font_list = robin_get_font_list();
	    return ( in_array( $input, $current_font_list ) ? $input : 'null' );
		}

		function robin_get_banner_positions() {
			if ( function_exists( 'robin_banner_positions' ) ) {
				$banner_position_list = array();
				foreach ( robin_banner_positions() as $key ) {
					$banner_position_list[] = esc_attr( $key );
				}
				return $banner_position_list;
			} else {
				return 0;
			}
		}

		function robin_sanitize_banner_positions( $input ) {
			if ( function_exists( 'robin_banner_positions' ) ) {
				$banner_positions = robin_get_banner_positions();
		    return ( in_array( $input, $banner_positions ) ? $input : 'null' );
			} else {
				return 0;
			}
		}

		function robin_sanitize_file( $file, $setting ) {
	    $mimes = array(
	        'jpg|jpeg|jpe' => 'image/jpeg',
	        'gif'          => 'image/gif',
	        'png'          => 'image/png'
	    );
	    $file_ext = wp_check_filetype( $file, $mimes );
	    return ( $file_ext['ext'] ? $file : $setting->default );
	  }

		function robin_sanitize_null( $input ) {
			return 0;
		}

		function robin_sanitize_let_html( $input ) {
			return force_balance_tags( wp_kses_post( $input ) );
		}

		function robin_sanitize_checkbox( $input ) {
			if ( $input == 1 ) {
				return 1;
			} else {
				return '';
			}
		}

		function robin_sanitize_choices( $input, $setting ) {
			global $wp_customize;
			$control = $wp_customize->get_control( $setting->id );
			if ( array_key_exists( $input, $control->choices ) ) {
				return $input;
			} else {
				return $setting->default;
			}
		}

		function robin_sanitize_integer( $input ) {
			if( is_numeric( $input ) ) {
				return intval( $input );
			}
		}
		/* */

		/* Allowed HTML */
		$robin_allowed_html = array(
				'a' => array(
					'href' => array(),
					'target' => array(),
			),
			'span' => array(
				'class' => array(),
			),
			'br' => array(),
			'em' => array(),
			'strong' => array(),
			'hr' => array(),
		);
		/* */

		////////////////////////////////////////////////////
		/*/////////////////// SECTIONS ///////////////////*/
		////////////////////////////////////////////////////

		$wp_customize->add_section( 'brnhmbx_robin_sectionFeaturedImage', array(
			'title' => esc_html__( '1. Featured Image Settings', 'robin' ),
			'priority' => 0,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionFonts', array(
			'title' => esc_html__( '2. Font Settings', 'robin' ),
			'priority' => 3,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionBackground', array(
			'title' => esc_html__( '3. Site Background', 'robin' ),
			'priority' => 5,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionHeader', array(
			'title' => esc_html__( '4. Header', 'robin' ),
			'priority' => 10,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionSlider', array(
			'title' => esc_html__( '5. Slider Settings', 'robin' ),
			'priority' => 15,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionHomeWidgets', array(
			'title' => esc_html__( '6. Sidebar, Upper & Home Widgets', 'robin' ),
			'priority' => 20,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionLayout', array(
			'title' => esc_html__( '7. Layout Options', 'robin' ),
			'priority' => 25,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionPostFormatStandard', array(
			'title' => esc_html__( '8. Post Format: Standard', 'robin' ),
			'priority' => 35,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionPostFormatGallery', array(
			'title' => esc_html__( '9. Post Format: Gallery', 'robin' ),
			'priority' => 40,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionPostFormatVideo', array(
			'title' => esc_html__( '10. Post Format: Video', 'robin' ),
			'priority' => 45,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionRP', array(
			'title' => esc_html__( '11. Related Posts', 'robin' ),
			'priority' => 50,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionFooter', array(
			'title' => esc_html__( '12. Footer', 'robin' ),
			'priority' => 60,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionShowHide', array(
			'title' => esc_html__( '13. Show/Hide Elements', 'robin' ),
			'priority' => 70,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionSocial', array(
			'title' => esc_html__( '14. Social Accounts', 'robin' ),
			'description' => wp_kses( __( 'Write the entire URL addresses.<br>Leave blank if not preferred.', 'robin' ), $robin_allowed_html ),
			'priority' => 75,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionGoogleMaps', array(
			'title' => esc_html__( '15. Google Maps', 'robin' ),
			'priority' => 80,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionTranslation', array(
			'title' => esc_html__( '16. Translation', 'robin' ),
			'priority' => 90,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionBanner', array(
			'title' => esc_html__( '17. Banner Management', 'robin' ),
			'priority' => 92,
		) );

		$wp_customize->add_section( 'brnhmbx_robin_sectionCSS', array(
			'title' => esc_html__( 'Custom CSS', 'robin' ),
			'description' => esc_html__( 'Write your CSS code to override styles.', 'robin' ),
			'priority' => 95,
		) );

		////////////////////////////////////////////////////
		/*/////////////////// SETTINGS ///////////////////*/
		////////////////////////////////////////////////////

		/* Featured Image Settings */
		if ( !function_exists( 'wp_site_icon' ) ) {
			$wp_customize->add_setting( 'brnhmbx_robin_upload_Favicon', array( 'sanitize_callback' => 'robin_sanitize_file' ) );
		}
		$wp_customize->add_setting( 'brnhmbx_robin_explanation_1', array( 'default' => '0', 'sanitize_callback' => 'robin_sanitize_null' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_imageWidth', array( 'default' => 1200, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_imageHeight', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_HomeImg_Standard', array( 'default' => 'fea', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_thumbnailImageWidth', array( 'default' => 600, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_thumbnailImageHeight', array( 'default' => 400, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		/* */

		/* Font Settings */
		$wp_customize->add_setting( 'brnhmbx_robin_font_1', array( 'default' => 'Quicksand', 'sanitize_callback' => 'robin_sanitize_select' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_font_1_bold', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_font_2', array( 'default' => 'Karla', 'sanitize_callback' => 'robin_sanitize_select' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_font_2_bold', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_font_3', array( 'default' => 'Karla', 'sanitize_callback' => 'robin_sanitize_select' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_font_3_bold', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );

		/* Site Background */
		$wp_customize->add_setting( 'brnhmbx_robin_color_Background', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_upload_Background', array( 'sanitize_callback' => 'robin_sanitize_file' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_centerBackground', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_repeatBackground', array( 'default' => 'no-repeat', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		/* */

		/* Header */
		$wp_customize->add_setting( 'brnhmbx_robin_text_Logo', array( 'default' => wp_title(), 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_font_Logo', array( 'default' => 'Montserrat', 'sanitize_callback' => 'robin_sanitize_select' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_font_size_Logo', array( 'default' => 30, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Logo', array( 'default' => '#333', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_upload_Logo', array( 'sanitize_callback' => 'robin_sanitize_file' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_upload_MobileLogo', array( 'sanitize_callback' => 'robin_sanitize_file' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_upload_StickyLogo', array( 'sanitize_callback' => 'robin_sanitize_file' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_MenuPos', array( 'default' => 'menu-center', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_MenuWidth', array( 'default' => 'boxed', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_menuContainerHeight', array( 'default' => 70, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_menuPaddingLeft', array( 'default' => 40, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_menuPaddingRight', array( 'default' => 20, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_triggerSlicknav', array( 'default' => 960, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'robin_slicknav_apl', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_LogoPos', array( 'default' => 'logo-top', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_maxLogoHeight', array( 'default' => 50, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_logoPaddingTop', array( 'default' => 40, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_logoPaddingRight', array( 'default' => 40, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_logoPaddingBottom', array( 'default' => 40, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_triggerSticky', array( 'default' => 300, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_StickyLogo', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_TopLineWidth', array( 'default' => 'full_boxed', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_SpotMessages', array( 'default' => 'tagline', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_explanation_5', array( 'default' => '0', 'sanitize_callback' => 'robin_sanitize_null' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_spotMessages_1', array( 'default' => 'Spot Message 1', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_spotMessages_2', array( 'default' => 'Spot Message 2', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_spotMessages_3', array( 'default' => 'Spot Message 3', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_spotDuration', array( 'default' => 4000, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_explanation_6', array( 'default' => '0', 'sanitize_callback' => 'robin_sanitize_null' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_HeaderBottomPadding', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_HeaderBottomPaddingInner', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_TopLineBottomPadding', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_stickyHeader', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_HeaderSocial', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_HeaderSearch', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_HeaderMenu', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_TopLine_Background', array( 'default' => '#333', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_transparent_TopLine_Background', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Logo_Background', array( 'default' => '#91c2ae', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_transparent_Logo_Background', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Menu_Background', array( 'default' => '#91c2ae', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_transparent_Menu_Background', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Menu_Border', array( 'default' => '#31795c', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_BorderedMenu', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_MenuLink', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_MenuLink_Hover', array( 'default' => '#31795c', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_MenuLevel_Background', array( 'default' => '#31795c', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_MenuLink_Level', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_MenuLink_Level_Hover', array( 'default' => '#91c2ae', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_HeaderLink', array( 'default' => '#91c2ae', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_HeaderLink_Hover', array( 'default' => '#31795c', 'sanitize_callback' => 'sanitize_hex_color' ) );
		/* */

		/* Slider Settings */
		$wp_customize->add_setting( 'brnhmbx_robin_explanation_7', array( 'default' => '0', 'sanitize_callback' => 'robin_sanitize_null' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sliderWidth', array( 'default' => 1200, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sliderHeight', array( 'default' => 600, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_SliderPosition', array( 'default' => 'cover', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sliderShortcode', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_staticfront', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_explanation_8', array( 'default' => '0', 'sanitize_callback' => 'robin_sanitize_null' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_bpts', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sliderCategory', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_bptsNumber', array( 'default' => 5, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_bptsExclude', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_SliderHomeView', array( 'default' => 'home-front', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sliderHideMobile', array( 'default' => 'always', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_bxControls_Main', array( 'default' => 'both', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_bxDarkControls', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_bxRectanglePagers', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_bxPagerPosition_Main', array( 'default' => 'center', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sliderPause', array( 'default' => 4000, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_bxAuto_Main', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sliderMode', array( 'default' => 'horizontal', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_explanation_9', array( 'default' => '0', 'sanitize_callback' => 'robin_sanitize_null' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_bptsDate', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_bptsComment', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_bptsCaption', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_bptsReadMore', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_bptsCategories', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_SliderArchive', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_SliderPost', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sliderInfinite', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sliderRandom', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Sli_Header', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Sli_Caption', array( 'default' => '#ffd3ce', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Sli_Box', array( 'default' => '#ff6f60', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_rng_Sli_Box', array( 'default' => 90, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		/* */

		/* Sidebar, Upper & Home Widgets */
		$wp_customize->add_setting( 'brnhmbx_robin_upperWidgetsCol', array( 'default' => '3col', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_UpperWidgetsFront', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_UpperWidgetsPage', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_UpperWidgetsPost', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_UpperWidgetsArchive', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_homeWidgetsCol', array( 'default' => '2col', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_HomeWidgetsFront', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_W_Title', array( 'default' => '#333', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_W_Sep', array( 'default' => '#ff6f60', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_W_Link', array( 'default' => '#333', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_W_LinkHover', array( 'default' => '#458cad', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_W_Content', array( 'default' => '#666', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_W_InputBackground', array( 'default' => '#f1ebdf', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_W_InputText', array( 'default' => '#999', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_explanation_10', array( 'default' => '0', 'sanitize_callback' => 'robin_sanitize_null' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_ListedTagCloud', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_CenteredArchiveList', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		/* */

		/* Layout Options */
		$wp_customize->add_setting( 'brnhmbx_robin_opt_PageWidth', array( 'default' => 'boxed', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_Layout', array( 'default' => '1col_sidebar', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_Layout_Archive', array( 'default' => '2col_sidebar', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_explanation_2', array( 'default' => '0', 'sanitize_callback' => 'robin_sanitize_null' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_styleZ_count', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_explanation_3', array( 'default' => '0', 'sanitize_callback' => 'robin_sanitize_null' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_minHeight_styleB', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_explanation_4', array( 'default' => '0', 'sanitize_callback' => 'robin_sanitize_null' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_SidebarPost_Standard', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_SidebarPost_Gallery', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_SidebarPost_Video', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_SidebarInnerPage', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_sh_SidebarShop', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_sh_SidebarProduct', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_ExtraSidebar_Archive', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_ExtraSidebar_Page', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_ExtraSidebar_Post', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		/* */

		/* Post Format: Standard */
		$wp_customize->add_setting( 'brnhmbx_robin_sh_FeaImg_Single_Standard', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_ignoreExcerpt_Standard', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_ignoreExcerpt_Standard_Archive', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_FeaImg_Standard', array( 'default' => 'fea', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_explanation_13', array( 'default' => '0', 'sanitize_callback' => 'robin_sanitize_null' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Standard_Background', array( 'default' => '#f4f1d3', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Standard_Header', array( 'default' => '#ff6f60', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Standard_Content', array( 'default' => '#333', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Standard_Link', array( 'default' => '#458cad', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Standard_Link_Hover', array( 'default' => '#31795c', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Standard_InputBackground', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Standard_InputText', array( 'default' => '#999', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Site_RMB', array( 'default' => '#e5e5e5', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Site_RMT', array( 'default' => '#333', 'sanitize_callback' => 'sanitize_hex_color' ) );
		/* */

		/* Post Format: Gallery */
		$wp_customize->add_setting( 'brnhmbx_robin_ignoreExcerpt_Gallery', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_ignoreExcerpt_Gallery_Archive', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_FeaImg_Gallery', array( 'default' => 'gal', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_GalleryPos_Gallery', array( 'default' => 'content', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_bxControls', array( 'default' => 'arrow', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_bxAuto', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_explanation_11', array( 'default' => '0', 'sanitize_callback' => 'robin_sanitize_null' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_keep_GalleryColors', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Gallery_Background', array( 'default' => '#f7edf0', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Gallery_Header', array( 'default' => '#5c7f71', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Gallery_Content', array( 'default' => '#5a3114', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Gallery_Link', array( 'default' => '#bd2d20', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Gallery_Link_Hover', array( 'default' => '#555', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Gallery_InputBackground', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Gallery_InputText', array( 'default' => '#999', 'sanitize_callback' => 'sanitize_hex_color' ) );
		/* */

		/* Post Format: Video */
		$wp_customize->add_setting( 'brnhmbx_robin_ignoreExcerpt_Video', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_ignoreExcerpt_Video_Archive', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_FeaImg_Video', array( 'default' => 'gal', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_explanation_12', array( 'default' => '0', 'sanitize_callback' => 'robin_sanitize_null' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_keep_VideoColors', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Video_Background', array( 'default' => '#484654', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Video_Header', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Video_Content', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Video_Link', array( 'default' => '#c4a2ba', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Video_Link_Hover', array( 'default' => '#c5bb50', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Video_InputBackground', array( 'default' => '#34333f', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Video_InputText', array( 'default' => '#999', 'sanitize_callback' => 'sanitize_hex_color' ) );
		/* */

		/* Related Posts */
		$wp_customize->add_setting( 'brnhmbx_robin_sh_RelatedPosts', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_RPDate', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_RPBase', array( 'default' => 'tag', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_RP_Header', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_RP_Box', array( 'default' => '#ff6f60', 'sanitize_callback' => 'sanitize_hex_color' ) );
		/* */

		/* Footer */
		$wp_customize->add_setting( 'brnhmbx_robin_opt_FooterWidgetsWidth', array( 'default' => 'boxed', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_footerWidgetsCol', array( 'default' => '4col', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_text_Footer', array( 'default' => '2019 Robin. All rights reserved.', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_InstagramShortcode', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_InstagramText', array( 'default' => 'follow @ instagram', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Footer', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_FooterWidgets', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_FooterBTT', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_FooterCopyright', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_FooterSocial', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_Footer_Background', array( 'default' => '#333', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_WF_Title', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_WF_Sep', array( 'default' => '#ff6f60', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_WF_Link', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_WF_LinkHover', array( 'default' => '#458cad', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_WF_Content', array( 'default' => '#999', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_WF_InputBackground', array( 'default' => '#222', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_color_WF_InputText', array( 'default' => '#999', 'sanitize_callback' => 'sanitize_hex_color' ) );
		/* */

		/* Show/Hide Elements */
		$wp_customize->add_setting( 'brnhmbx_robin_sh_PostComments', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_PageComments', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_FilterBar', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_FilterBar_Word', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Date', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Date_Home', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_btnComments', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_btnComments_Home', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Excerpt', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Excerpt_Home', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_TagBar', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_TagBar_Home', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_CategoryBar', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_CategoryBar_Home', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_btnReadMore', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Author', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_AuthorBox', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_SocialBar', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_SocialBar_Page', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_SocialBar_Facebook', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_SocialBar_Twitter', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_SocialBar_Google', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_PageNaviBullet', array( 'default' => 'image', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_iconAsterisk', array( 'default' => '-', 'sanitize_callback' => 'sanitize_text_field' ) );
		/* */

		/* Social Accounts */
		$wp_customize->add_setting( 'brnhmbx_robin_sh_SocialAccounts', array( 'default' => 1, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_Facebook', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_Twitter', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_Instagram', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_Pinterest', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_Google', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_Tumblr', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_Flickr', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_Digg', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_LinkedIn', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_Vimeo', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_YouTube', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_Behance', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_Dribble', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_DeviantArt', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_Github', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_Bloglovin', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_Lastfm', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_SoundCloud', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_social_VK', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		/* */

		/* Google Maps */
		$wp_customize->add_setting( 'brnhmbx_robin_mapPage', array( 'sanitize_callback' => 'robin_returnMapPageID' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_coorN', array( 'default' => '49.0138', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_coorE', array( 'default' => '8.38624', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_rng_MapZoom', array( 'default' => 15, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_mapHeight', array( 'default' => 500, 'sanitize_callback' => 'robin_sanitize_integer' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Map', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_enableMapKey', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_mapAPI', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
		/* */

		/* Translation */
		$wp_customize->add_setting( 'brnhmbx_robin_IgnorePOT', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Lang', array( 'default' => ( get_bloginfo( 'language' ) ), 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_404', array( 'default' => 'Page not found.', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Nothing', array( 'default' => 'Nothing found.', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_SearchResults', array( 'default' => 'Search Results', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Page', array( 'default' => 'Page', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Tag', array( 'default' => 'Tag', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Category', array( 'default' => 'Category', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Author', array( 'default' => 'Author', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Archives', array( 'default' => 'Archives', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Older', array( 'default' => 'Older', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Newer', array( 'default' => 'Newer', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_By', array( 'default' => 'by', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Keyword', array( 'default' => 'Type keyword to search', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_ReadMore', array( 'default' => 'Read More', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_RelatedPosts', array( 'default' => 'Related Posts', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Comment', array( 'default' => 'Comment', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_comment', array( 'default' => 'comment', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Comments', array( 'default' => 'Comments', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_comments', array( 'default' => 'comments', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Name', array( 'default' => 'Name', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Email', array( 'default' => 'E-mail', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Website', array( 'default' => 'Website', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_MustBeLogged', array( 'default' => 'You must be logged in to post a comment.', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Logged', array( 'default' => 'Logged In', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_LogOut', array( 'default' => 'Log Out', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_LeaveReply', array( 'default' => 'Leave a Reply', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_CancelReply', array( 'default' => 'Cancel Reply', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_PostComment', array( 'default' => 'Post Comment', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_At', array( 'default' => 'at', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Reply', array( 'default' => 'Reply', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Edit', array( 'default' => 'Edit', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_Awaiting', array( 'default' => 'Comment awaiting approval.', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_About', array( 'default' => 'About', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_AllByAuthor', array( 'default' => 'View All Posts by Author', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_tra_AuthorWebsite', array( 'default' => 'Visit Author Website', 'sanitize_callback' => 'sanitize_text_field' ) );
		/* */

		/* Banner Management */
		$wp_customize->add_setting( 'brnhmbx_robin_opt_ResponsiveBannerHide', array( 'default' => '640', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_text_Banner_1', array( 'default' => '', 'sanitize_callback' => 'robin_sanitize_let_html' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_BannerPos_1', array( 'default' => 'above-full-slider', 'sanitize_callback' => 'robin_sanitize_banner_positions' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_ResponsiveBanner_1', array( 'default' => 'static', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Banner_1_Archive', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Banner_1_Post', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_text_Banner_2', array( 'default' => '', 'sanitize_callback' => 'robin_sanitize_let_html' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_BannerPos_2', array( 'default' => 'below-among-slider', 'sanitize_callback' => 'robin_sanitize_banner_positions' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_ResponsiveBanner_2', array( 'default' => 'static', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Banner_2_Archive', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Banner_2_Post', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_text_Banner_3', array( 'default' => '', 'sanitize_callback' => 'robin_sanitize_let_html' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_BannerPos_3', array( 'default' => 'below-blog-posts', 'sanitize_callback' => 'robin_sanitize_banner_positions' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_ResponsiveBanner_3', array( 'default' => 'static', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Banner_3_Archive', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Banner_3_Post', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_text_Banner_4', array( 'default' => '', 'sanitize_callback' => 'robin_sanitize_let_html' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_BannerPos_4', array( 'default' => 'below-page', 'sanitize_callback' => 'robin_sanitize_banner_positions' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_ResponsiveBanner_4', array( 'default' => 'static', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Banner_4_Archive', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Banner_4_Post', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_text_Banner_5', array( 'default' => '', 'sanitize_callback' => 'robin_sanitize_let_html' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_BannerPos_5', array( 'default' => 'below-home-widgets', 'sanitize_callback' => 'robin_sanitize_banner_positions' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_opt_ResponsiveBanner_5', array( 'default' => 'static', 'sanitize_callback' => 'robin_sanitize_choices' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Banner_5_Archive', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'brnhmbx_robin_sh_Banner_5_Post', array( 'default' => 0, 'sanitize_callback' => 'robin_sanitize_checkbox' ) );
		/* */

		/* Custom CSS */
		$wp_customize->add_setting( 'brnhmbx_robin_text_CSS', array( 'default' => '', 'sanitize_callback' => 'robin_sanitize_let_html' ) );
		/* */

		////////////////////////////////////////////////////
		/*/////////////////// CONTROLS ///////////////////*/
		////////////////////////////////////////////////////

		/* Featured Image Settings */
		$wp_customize->add_control( 'brnhmbx_robin_explanation_1', array(
			'label' => esc_html__( 'Important Note', 'robin' ),
			'description' => wp_kses( __( 'When you upload an image into your media library, it gets the sizes below. If you change these settings AFTER you uploaded an image, the image will not change its sizes. So, you have to re-upload it or use a plugin like <a href="https://wordpress.org/plugins/regenerate-thumbnails/" target="_blank">Regenerate Thumbnails</a> which is a very good practice.', 'robin' ), $robin_allowed_html ),
			'section' => 'brnhmbx_robin_sectionFeaturedImage',
			'settings' => 'brnhmbx_robin_explanation_1',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_imageWidth', array(
			'label' => esc_html__( '1.1. Featured Image Width', 'robin' ),
			'description' => wp_kses( __( 'Theme default: "1200"<br>Write "0" to not to resize the images.<br>Works for newly added images only.', 'robin' ), $robin_allowed_html ),
			'section' => 'brnhmbx_robin_sectionFeaturedImage',
			'settings' => 'brnhmbx_robin_imageWidth',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_imageHeight', array(
			'label' => esc_html__( '1.2. Featured Image Height', 'robin' ),
			'description' => wp_kses( __( 'Theme default: "0"<br>Write "0" to not to crop the images.<br>Works for newly added images only.', 'robin' ), $robin_allowed_html ),
			'section' => 'brnhmbx_robin_sectionFeaturedImage',
			'settings' => 'brnhmbx_robin_imageHeight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_thumbnailImageWidth', array(
			'label' => esc_html__( '1.3. Thumbnail Image Width', 'robin' ),
			'description' => wp_kses( __( 'Theme default: "600"<br>Used in related posts, widgets etc.<br>Write "0" to not to crop the images.<br>Works for newly added images only.', 'robin' ), $robin_allowed_html ),
			'section' => 'brnhmbx_robin_sectionFeaturedImage',
			'settings' => 'brnhmbx_robin_thumbnailImageWidth',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_thumbnailImageHeight', array(
			'label' => esc_html__( '1.4. Thumbnail Image Height', 'robin' ),
			'description' => wp_kses( __( 'Theme default: "400"<br>Used in related posts, widgets etc.<br>Write "0" to not to crop the images.<br>Works for newly added images only.', 'robin' ), $robin_allowed_html ),
			'section' => 'brnhmbx_robin_sectionFeaturedImage',
			'settings' => 'brnhmbx_robin_thumbnailImageHeight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_HomeImg_Standard', array(
			'label' => esc_html__( '1.5. Home Thumbnail Options', 'robin' ),
			'description' => esc_html__( 'Does not affect post pages.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFeaturedImage',
			'settings' => 'brnhmbx_robin_opt_HomeImg_Standard',
			'type' => 'radio',
			'choices' => array(
				'home' => 'Use Thumbnail Image',
				'fea' => 'Use Featured Image'
			)
		) );
		/* */

		/* Font Settings */
		$wp_customize->add_control( new robin_font_selector( $wp_customize, 'brnhmbx_robin_font_1', array(
			'label' => esc_html__( '2.1. Primary Font', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFonts',
			'description' => wp_kses( __( 'Menu items, main headers etc.<br>Theme default: "Quicksand"', 'robin' ), $robin_allowed_html ),
			'settings' => 'brnhmbx_robin_font_1'
		) ) );
		$wp_customize->add_control( 'brnhmbx_robin_font_1_bold', array(
			'label' => esc_html__( 'Use Bold Where Allowed', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFonts',
			'settings' => 'brnhmbx_robin_font_1_bold',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new robin_font_selector( $wp_customize, 'brnhmbx_robin_font_2', array(
			'label' => esc_html__( '2.2. Secondary Font', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFonts',
			'description' => wp_kses( __( 'Content font.<br>Theme default: "Karla"', 'robin' ), $robin_allowed_html ),
			'settings' => 'brnhmbx_robin_font_2',
		) ) );
		$wp_customize->add_control( 'brnhmbx_robin_font_2_bold', array(
			'label' => esc_html__( 'Use Bold Where Allowed', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFonts',
			'settings' => 'brnhmbx_robin_font_2_bold',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new robin_font_selector( $wp_customize, 'brnhmbx_robin_font_3', array(
			'label' => esc_html__( '2.3. Tertiary Font', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFonts',
			'description' => wp_kses( __( 'Dates, miscellaneous etc.<br>Theme default: "Karla"', 'robin' ), $robin_allowed_html ),
			'settings' => 'brnhmbx_robin_font_3',
		) ) );
		$wp_customize->add_control( 'brnhmbx_robin_font_3_bold', array(
			'label' => esc_html__( 'Use Bold Where Allowed', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFonts',
			'settings' => 'brnhmbx_robin_font_3_bold',
			'type' => 'checkbox'
		) );
		/* */

		/* Site Background */
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Background', array(
			'label' => esc_html__( '3.1. Background Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionBackground', 'settings' => 'brnhmbx_robin_color_Background'
		) ) );
		$wp_customize->add_control(
			new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_robin_upload_Background', array(
					'label' => esc_html__( '3.2. Background Image', 'robin' ),

					'section' => 'brnhmbx_robin_sectionBackground',
					'settings' => 'brnhmbx_robin_upload_Background'
				)
			)
		);
		$wp_customize->add_control( 'brnhmbx_robin_centerBackground', array(
			'label' => esc_html__( 'Centered Background Image', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBackground',
			'settings' => 'brnhmbx_robin_centerBackground',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_repeatBackground', array(
			'label' => esc_html__( '3.3. Background Repeat Options', 'robin' ),
			'description' => esc_html__( 'Only used if "Centered" is unchecked.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBackground',
			'settings' => 'brnhmbx_robin_repeatBackground',
			'type' => 'radio',
			'choices' => array(
				'no-repeat' => 'No Repeat',
				'repeat-x' => 'Repeat Only Horizontally',
				'repeat-y' => 'Repeat Only Vertically',
			)
		) );
		/* */

		/* Header */
		if ( !function_exists( 'wp_site_icon' ) ) {
			$wp_customize->add_control(
				new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_robin_upload_Favicon', array(
						'label' => esc_html__( 'Upload a Favicon', 'robin' ),

						'section' => 'brnhmbx_robin_sectionFeaturedImage',
						'settings' => 'brnhmbx_robin_upload_Favicon'
					)
				)
			);
		}
		$wp_customize->add_control( 'brnhmbx_robin_text_Logo', array(
			'label' => esc_html__( '4.1. Logo Text', 'robin' ),
			'description' => esc_html__( 'Leave blank if you want to use the "Site Title". If a logo image is uploaded, this will never be shown.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_text_Logo',
			'type' => 'text',
		) );
		$wp_customize->add_control( new robin_font_selector( $wp_customize, 'brnhmbx_robin_font_Logo', array(
			'label' => esc_html__( '4.2. Logo Font', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'description' => esc_html__( 'Theme default: "Montserrat"', 'robin' ),
			'settings' => 'brnhmbx_robin_font_Logo'
		) ) );
		$wp_customize->add_control( 'brnhmbx_robin_font_size_Logo', array(
			'label' => esc_html__( '4.3. Logo Font Size', 'robin' ),
			'description' => esc_html__( 'Theme default: "30"(px)', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_font_size_Logo',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 50px;',
			),
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Logo', array(
			'label' => esc_html__( '4.4. Logo Text Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHeader', 'settings' => 'brnhmbx_robin_color_Logo'
		) ) );
		$wp_customize->add_control(
			new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_robin_upload_Logo', array(
					'label' => esc_html__( '4.5. Logo Image', 'robin' ),
					'section' => 'brnhmbx_robin_sectionHeader',
					'settings' => 'brnhmbx_robin_upload_Logo'
				)
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_robin_upload_MobileLogo', array(
					'label' => esc_html__( 'Mobile Logo Image', 'robin' ),
					'section' => 'brnhmbx_robin_sectionHeader',
					'settings' => 'brnhmbx_robin_upload_MobileLogo'
				)
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_robin_upload_StickyLogo', array(
					'label' => esc_html__( '4.6. Sticky Logo Image', 'robin' ),
					'section' => 'brnhmbx_robin_sectionHeader',
					'settings' => 'brnhmbx_robin_upload_StickyLogo'
				)
			)
		);
		$wp_customize->add_control( 'brnhmbx_robin_opt_MenuPos', array(
			'label' => esc_html__( '4.7. Menu Position', 'robin' ),

			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_opt_MenuPos',
			'type' => 'radio',
			'choices' => array(
				'menu-left' => 'Left',
				'menu-center' => 'Center',
				'menu-right' => 'Right'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_MenuWidth', array(
			'label' => esc_html__( '4.8. Menu Container Width', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',

			'settings' => 'brnhmbx_robin_opt_MenuWidth',
			'type' => 'radio',
			'choices' => array(
				'boxed' => 'Boxed',
				'full' => 'Fullwidth',
				'full_boxed' => 'Fullwidth Background + Boxed'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_menuContainerHeight', array(
			'label' => esc_html__( '4.9. Menu Container Height', 'robin' ),
			'description' => esc_html__( 'min 60.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_menuContainerHeight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_menuPaddingLeft', array(
			'label' => esc_html__( '4.10. Menu Container Left Padding', 'robin' ),

			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_menuPaddingLeft',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_menuPaddingRight', array(
			'label' => esc_html__( '4.11. Menu Container Right Padding', 'robin' ),

			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_menuPaddingRight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_triggerSlicknav', array(
			'label' => esc_html__( '4.12. Trigger Mobile Menu', 'robin' ),
			'description' => esc_html__( 'Trigger mobile menu when window width is smaller than:', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_triggerSlicknav',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 80px;',
			),
		) );
		$wp_customize->add_control( 'robin_slicknav_apl', array(
			'label' => esc_html__( 'Clickable Parent Menu Items in Mobile Menu', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'robin_slicknav_apl',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_LogoPos', array(
			'label' => esc_html__( '4.13. Logo Position', 'robin' ),

			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_opt_LogoPos',
			'type' => 'radio',
			'choices' => array(
				'logo-top' => 'Top',
				'logo-left' => 'Left',
				'logo-bottom' => 'Bottom'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_maxLogoHeight', array(
			'label' => esc_html__( '4.14. Logo Height', 'robin' ),
			'description' => esc_html__( 'Will be ignored if higher than "Menu Container Height" when "Logo Position" is "Left". Only used if a logo image is uploaded.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_maxLogoHeight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 50px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_logoPaddingTop', array(
			'label' => esc_html__( '4.15. Logo Top Padding', 'robin' ),
			'description' => esc_html__( 'Only used if "Logo Position" is NOT "Left".', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_logoPaddingTop',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_logoPaddingRight', array(
			'label' => esc_html__( '4.16. Logo Right Padding', 'robin' ),
			'description' => esc_html__( 'Space between the logo and the menu. Only used if "Logo Position" is "Left".', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_logoPaddingRight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_logoPaddingBottom', array(
			'label' => esc_html__( '4.17. Logo Bottom Padding', 'robin' ),
			'description' => esc_html__( 'Only used if "Logo Position" is NOT "Left".', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_logoPaddingBottom',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_triggerSticky', array(
			'label' => esc_html__( '4.18. Sticky Header', 'robin' ),
			'description' => esc_html__( 'Trigger sticky header when scroll position is higher than:', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_triggerSticky',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 80px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_stickyHeader', array(
			'label' => esc_html__( 'Sticky Header', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_stickyHeader',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_TopLineWidth', array(
			'label' => esc_html__( '4.19. Top Line Container Width', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',

			'settings' => 'brnhmbx_robin_opt_TopLineWidth',
			'type' => 'radio',
			'choices' => array(
				'boxed' => 'Boxed',
				'full' => 'Fullwidth',
				'full_boxed' => 'Fullwidth Background + Boxed'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_SpotMessages', array(
			'label' => esc_html__( '4.20. Tagline Options', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',

			'settings' => 'brnhmbx_robin_opt_SpotMessages',
			'type' => 'radio',
			'choices' => array(
				'tagline' => 'Show Tagline',
				'spot' => 'Show Spot Messages',
				'none' => 'Hide'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_explanation_5', array(
			'label' => esc_html__( '4.21. Spot Messages', 'robin' ),
			'description' => wp_kses( __( 'Only used if "Show Spot Messages" is selected. You can use <a href="http://fortawesome.github.io/Font-Awesome/cheatsheet/" target="_blank">Font Awesome</a> here.', 'robin' ), $robin_allowed_html ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_explanation_5',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_spotMessages_1', array(
			'label' => esc_html__( 'Spot Message 1', 'robin' ),

			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_spotMessages_1',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_spotMessages_2', array(
			'label' => esc_html__( 'Spot Message 2', 'robin' ),

			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_spotMessages_2',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_spotMessages_3', array(
			'label' => esc_html__( 'Spot Message 3', 'robin' ),

			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_spotMessages_3',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_spotDuration', array(
			'label' => esc_html__( 'Spot Message Duration', 'robin' ),
			'description' => esc_html__( 'Theme default: "4000"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_spotDuration',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 80px; margin-bottom: 20px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_explanation_6', array(
			'label' => esc_html__( '4.22. Show/Hide', 'robin' ),

			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_explanation_6',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_HeaderBottomPadding', array(
			'label' => esc_html__( 'Padding Below Menu (For Homepage)', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_sh_HeaderBottomPadding',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_HeaderBottomPaddingInner', array(
			'label' => esc_html__( 'Padding Below Menu', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_sh_HeaderBottomPaddingInner',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_TopLineBottomPadding', array(
			'label' => esc_html__( 'Padding Below Top Line', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_sh_TopLineBottomPadding',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_StickyLogo', array(
			'label' => esc_html__( 'Show Sticky Logo', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_sh_StickyLogo',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_HeaderSocial', array(
			'label' => esc_html__( 'Show Social Account Icons', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_sh_HeaderSocial',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_HeaderSearch', array(
			'label' => esc_html__( 'Show Search', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_sh_HeaderSearch',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_HeaderMenu', array(
			'label' => esc_html__( 'Show Header Menu', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_sh_HeaderMenu',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_TopLine_Background', array(
			'label' => esc_html__( 'Top Line Background Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHeader', 'settings' => 'brnhmbx_robin_color_TopLine_Background'
		) ) );
		$wp_customize->add_control( 'brnhmbx_robin_transparent_TopLine_Background', array(
			'label' => esc_html__( 'Transparent Top Line Background', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_transparent_TopLine_Background',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Logo_Background', array(
			'label' => esc_html__( 'Logo Background Color', 'robin' ), 'description' => esc_html__( 'Only used if "Logo Position" is NOT "Left".', 'robin' ), 'section' => 'brnhmbx_robin_sectionHeader', 'settings' => 'brnhmbx_robin_color_Logo_Background'
		) ) );
		$wp_customize->add_control( 'brnhmbx_robin_transparent_Logo_Background', array(
			'label' => esc_html__( 'Transparent Logo Background', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_transparent_Logo_Background',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Menu_Background', array(
			'label' => esc_html__( 'Menu Background Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHeader', 'settings' => 'brnhmbx_robin_color_Menu_Background'
		) ) );
		$wp_customize->add_control( 'brnhmbx_robin_transparent_Menu_Background', array(
			'label' => esc_html__( 'Transparent Menu Background', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_transparent_Menu_Background',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Menu_Border', array(
			'label' => esc_html__( 'Menu Border Color', 'robin' ), 'description' => esc_html__( 'Only used if "Bordered Menu Container" is checked.', 'robin' ), 'section' => 'brnhmbx_robin_sectionHeader', 'settings' => 'brnhmbx_robin_color_Menu_Border'
		) ) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_BorderedMenu', array(
			'label' => esc_html__( 'Bordered Menu Container', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHeader',
			'settings' => 'brnhmbx_robin_sh_BorderedMenu',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_MenuLink', array(
			'label' => esc_html__( 'Menu Link Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHeader', 'settings' => 'brnhmbx_robin_color_MenuLink'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_MenuLink_Hover', array(
			'label' => esc_html__( 'Menu Link Hover Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHeader', 'settings' => 'brnhmbx_robin_color_MenuLink_Hover'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_MenuLevel_Background', array(
			'label' => esc_html__( 'Menu Level Background Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHeader', 'settings' => 'brnhmbx_robin_color_MenuLevel_Background'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_MenuLink_Level', array(
			'label' => esc_html__( 'Menu Level Link Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHeader', 'settings' => 'brnhmbx_robin_color_MenuLink_Level'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_MenuLink_Level_Hover', array(
			'label' => esc_html__( 'Menu Level Link Hover Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHeader', 'settings' => 'brnhmbx_robin_color_MenuLink_Level_Hover'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_HeaderLink', array(
			'label' => esc_html__( 'Header Menu Link Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHeader', 'settings' => 'brnhmbx_robin_color_HeaderLink'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_HeaderLink_Hover', array(
			'label' => esc_html__( 'Header Menu Link Hover Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHeader', 'settings' => 'brnhmbx_robin_color_HeaderLink_Hover'
		) ) );
		/* */

		/* Slider Settings */
		$wp_customize->add_control( 'brnhmbx_robin_explanation_7', array(
			'label' => esc_html__( 'Important Note', 'robin' ),
			'description' => wp_kses( __( 'When you upload an image into your media library, it gets the sizes below. If you change these settings AFTER you uploaded an image, the image will not change its sizes. So, you have to re-upload it or use a plugin like <a href="https://wordpress.org/plugins/regenerate-thumbnails/" target="_blank">Regenerate Thumbnails</a> which is a very good practice.', 'robin' ), $robin_allowed_html ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_explanation_7',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sliderWidth', array(
			'label' => esc_html__( '5.1. Slide Image Width', 'robin' ),
			'description' => wp_kses( __( 'Theme default: "1200"<br>Since the slider is responsive, display results may seem different. If you want to use "Fullwidth" option for instance, to set it 2560 and upload big images make sense.<br>Works for only new added images.', 'robin' ), $robin_allowed_html ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_sliderWidth',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sliderHeight', array(
			'label' => esc_html__( '5.2. Slide Image Height', 'robin' ),
			'description' => wp_kses( __( 'Theme default: "600"<br>This value is fixed, not responsive.<br>Works for only new added images.', 'robin' ), $robin_allowed_html ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_sliderHeight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_SliderPosition', array(
			'label' => esc_html__( '5.3. Slider Position & View', 'robin' ),
			'description' => wp_kses( __( 'When you choose "Fullwidth" for slider, it makes the container fullwidth, not the image. So, you should try to upload a bigger image or use a plugin like <a href="https://wordpress.org/plugins/regenerate-thumbnails/" target="_blank">Regenerate Thumbnails</a> to resize the uploaded images if they are already big enough.', 'robin' ), $robin_allowed_html ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_opt_SliderPosition',
			'type' => 'radio',
			'choices' => array(
				'full' => 'Fullwidth',
				'cover' => 'Cover',
				'among' => 'Among the Posts'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sliderShortcode', array(
			'label' => esc_html__( '5.4. Shortcode', 'robin' ),
			'description' => wp_kses( __( 'Example usages:<br>Old Slider:<br>[robinslider group="your_group"]<br>New Slider:<br>[new_robinslider group="your_group"]', 'robin' ), $robin_allowed_html ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_sliderShortcode',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_staticfront', array(
			'label' => esc_html__( 'Show Slider on Static Front Page', 'robin' ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_staticfront',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_explanation_8', array(
			'label' => esc_html__( '5.5. Blog Posts in Slider', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_explanation_8',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_bpts', array(
			'label' => esc_html__( 'Show Blog Posts in Slider', 'robin' ),
			'description' => esc_html__( 'Disables the shortcode if checked.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_bpts',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sliderCategory', array(
			'description' => esc_html__( 'Write a category slug to show the category posts in slider. Leave blank to show all posts. Only used if "Show Blog Posts in Slider" is checked.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_sliderCategory',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_bptsNumber', array(
			'description' => wp_kses( __( 'Number of the posts to show in slider:<br>Only used if "Show Blog Posts in Slider" is checked.', 'robin' ), $robin_allowed_html ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_bptsNumber',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_bptsExclude', array(
			'label' => esc_html__( 'Exclude the Slider Posts From Feed', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_bptsExclude',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_SliderHomeView', array(
			'label' => esc_html__( '5.6. Home View Options', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_opt_SliderHomeView',
			'type' => 'radio',
			'choices' => array(
				'home-all' => 'During Pagination',
				'home-front' => 'Only on the First Page of Pagination',
				'home-hide' => 'Hide at Home'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sliderHideMobile', array(
			'label' => esc_html__( '5.7. Mobile Settings', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_sliderHideMobile',
			'type' => 'radio',
			'choices' => array(
				'always' => 'Always Show',
				'320' => 'Hide at 320px',
				'480' => 'Hide at 480px',
				'640' => 'Hide at 640px'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_bxControls_Main', array(
			'label' => esc_html__( '5.8. Control Settings', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_opt_bxControls_Main',
			'type' => 'radio',
			'choices' => array(
				'arrow' => 'Show Prev/Next Arrows',
				'bullet' => 'Show Pager Bullets',
				'both' => 'Show Both',
				'none' => 'None'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_bxDarkControls', array(
			'label' => esc_html__( 'Use Dark Bullets/Arrows', 'robin' ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_sh_bxDarkControls',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_bxRectanglePagers', array(
			'label' => esc_html__( 'Use Rectangle Bullets', 'robin' ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_sh_bxRectanglePagers',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_bxPagerPosition_Main', array(
			'label' => esc_html__( '5.9. Pager Bullets Position', 'robin' ),
			'description' => esc_html__( 'Only used if "Show Pager Bullets" or "Show Both" is selected.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_opt_bxPagerPosition_Main',
			'type' => 'radio',
			'choices' => array(
				'left' => 'Left',
				'center' => 'Center',
				'right' => 'Right'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sliderPause', array(
			'label' => esc_html__( '5.10. Autoplay Duration', 'robin' ),
			'description' => wp_kses( __( 'Theme default: "4000"<br>Only used if "Autoplay Slides" is checked.', 'robin' ), $robin_allowed_html ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_sliderPause',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_bxAuto_Main', array(
			'label' => esc_html__( 'Autoplay Slides', 'robin' ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_bxAuto_Main',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sliderMode', array(
			'label' => esc_html__( '5.11. Transition Effect', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_sliderMode',
			'type' => 'radio',
			'choices' => array(
				'horizontal' => 'Horizontal',
				'fade' => 'Fade'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_explanation_9', array(
			'label' => esc_html__( '5.12. Show/Hide & Other Options', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_explanation_9',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_bptsDate', array(
			'label' => esc_html__( 'Show Post Dates', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_bptsDate',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_bptsComment', array(
			'label' => esc_html__( 'Show Post Comments Icon', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_bptsComment',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_bptsCaption', array(
			'label' => esc_html__( 'Show Excerpt', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_bptsCaption',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_bptsReadMore', array(
			'label' => esc_html__( 'Show "Read More" Button', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_bptsReadMore',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_bptsCategories', array(
			'label' => esc_html__( 'Show Categories', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_bptsCategories',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_SliderArchive', array(
			'label' => esc_html__( 'Show Slider on Archive Pages', 'robin' ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_sh_SliderArchive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_SliderPost', array(
			'label' => esc_html__( 'Show Slider on Post Pages', 'robin' ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_sh_SliderPost',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sliderInfinite', array(
			'label' => esc_html__( 'Infinite Loop', 'robin' ),
			'description' => esc_html__( 'If checked, clicking "Next" while on the last slide will transition to the first slide and vice-versa.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_sliderInfinite',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sliderRandom', array(
			'label' => esc_html__( 'Start with a Random Slide', 'robin' ),
			'section' => 'brnhmbx_robin_sectionSlider',
			'settings' => 'brnhmbx_robin_sliderRandom',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Sli_Header', array(
			'label' => esc_html__( 'Header Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionSlider', 'settings' => 'brnhmbx_robin_color_Sli_Header'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Sli_Caption', array(
			'label' => esc_html__( 'Excerpt Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionSlider', 'settings' => 'brnhmbx_robin_color_Sli_Caption'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Sli_Box', array(
			'label' => esc_html__( 'Box Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionSlider', 'settings' => 'brnhmbx_robin_color_Sli_Box'
		) ) );
		$wp_customize->add_control( 'brnhmbx_robin_rng_Sli_Box', array(
			'type'        => 'range',
			'section'     => 'brnhmbx_robin_sectionSlider',
			'label'       => 'Slider Box Opacity',

			'input_attrs' => array(
				'min'   => 0,
				'max'   => 100,
				'step'  => 10
			)
		) );
		/* */

		/* Sidebar, Upper & Home Widgets */
		$wp_customize->add_control( 'brnhmbx_robin_upperWidgetsCol', array(
			'label' => esc_html__( '6.1. Upper Widget Columns', 'robin' ),
			'description' => esc_html__( '3 columns option is only used with layouts have no sidebar.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHomeWidgets',
			'settings' => 'brnhmbx_robin_upperWidgetsCol',
			'type' => 'radio',
			'choices' => array(
				'2col' => '2 Columns',
				'3col' => '3 Columns'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_UpperWidgetsFront', array(
			'label' => esc_html__( 'First Page Upper Widgets', 'robin' ),
			'description' => esc_html__( 'Shows upper widgets only on the first page of pagination.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHomeWidgets',
			'settings' => 'brnhmbx_robin_sh_UpperWidgetsFront',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_UpperWidgetsPage', array(
			'label' => esc_html__( 'Show Upper Widgets on Pages', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHomeWidgets',
			'settings' => 'brnhmbx_robin_sh_UpperWidgetsPage',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_UpperWidgetsPost', array(
			'label' => esc_html__( 'Show Upper Widgets on Posts', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHomeWidgets',
			'settings' => 'brnhmbx_robin_sh_UpperWidgetsPost',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_UpperWidgetsArchive', array(
			'label' => esc_html__( 'Show Upper Widgets on Archives', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHomeWidgets',
			'settings' => 'brnhmbx_robin_sh_UpperWidgetsArchive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_homeWidgetsCol', array(
			'label' => esc_html__( '6.2. Home Widget Columns', 'robin' ),
			'description' => esc_html__( '3 columns option is only used with layouts have no sidebar.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHomeWidgets',
			'settings' => 'brnhmbx_robin_homeWidgetsCol',
			'type' => 'radio',
			'choices' => array(
				'2col' => '2 Columns',
				'3col' => '3 Columns'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_HomeWidgetsFront', array(
			'label' => esc_html__( 'First Page Home Widgets', 'robin' ),
			'description' => esc_html__( 'Shows home widgets only on the first page of pagination.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHomeWidgets',
			'settings' => 'brnhmbx_robin_sh_HomeWidgetsFront',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_W_Title', array(
			'label' => esc_html__( 'Title Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHomeWidgets', 'settings' => 'brnhmbx_robin_color_W_Title'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_W_Sep', array(
			'label' => esc_html__( 'Separator Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHomeWidgets', 'settings' => 'brnhmbx_robin_color_W_Sep'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_W_Link', array(
			'label' => esc_html__( 'Link Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHomeWidgets', 'settings' => 'brnhmbx_robin_color_W_Link'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_W_LinkHover', array(
			'label' => esc_html__( 'Link Hover Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHomeWidgets', 'settings' => 'brnhmbx_robin_color_W_LinkHover'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_W_Content', array(
			'label' => esc_html__( 'Content Color', 'robin' ), 'description' => esc_html__( 'Used for text widgets, dates etc.', 'robin' ), 'section' => 'brnhmbx_robin_sectionHomeWidgets', 'settings' => 'brnhmbx_robin_color_W_Content'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_W_InputBackground', array(
			'label' => esc_html__( 'Input Background Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHomeWidgets', 'settings' => 'brnhmbx_robin_color_W_InputBackground'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_W_InputText', array(
			'label' => esc_html__( 'Input Text Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionHomeWidgets', 'settings' => 'brnhmbx_robin_color_W_InputText'
		) ) );
		$wp_customize->add_control( 'brnhmbx_robin_explanation_10', array(
			'label' => esc_html__( '6.3. WP Default Widget Options', 'robin' ),
			'description' => esc_html__( 'The options below affects footer widgets too.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionHomeWidgets',
			'settings' => 'brnhmbx_robin_explanation_10',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_ListedTagCloud', array(
			'label' => esc_html__( 'Fixed Size Tag Cloud', 'robin' ),

			'section' => 'brnhmbx_robin_sectionHomeWidgets',
			'settings' => 'brnhmbx_robin_sh_ListedTagCloud',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_CenteredArchiveList', array(
			'label' => esc_html__( 'Centered Archive/Category List', 'robin' ),

			'section' => 'brnhmbx_robin_sectionHomeWidgets',
			'settings' => 'brnhmbx_robin_sh_CenteredArchiveList',
			'type' => 'checkbox'
		) );
		/* */

		/* Layout Options */
		$wp_customize->add_control( 'brnhmbx_robin_opt_PageWidth', array(
			'label' => esc_html__( '7.1. Container Width', 'robin' ),
			'section' => 'brnhmbx_robin_sectionLayout',

			'settings' => 'brnhmbx_robin_opt_PageWidth',
			'type' => 'radio',
			'choices' => array(
				'boxed' => 'Boxed',
				'full' => 'Fullwidth'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_Layout', array(
			'label' => esc_html__( '7.2. Home Display Options', 'robin' ),
			'section' => 'brnhmbx_robin_sectionLayout',
			'settings' => 'brnhmbx_robin_opt_Layout',
			'type' => 'radio',
			'choices' => array(
				'1col' => '1 Column',
				'1col_sidebar' => '1 Column + Sidebar',
				'2col' => '2 Columns',
				'2col_sidebar' => '2 Columns + Sidebar',
				'1_2col_sidebar' => '(1 + 2) Columns + Sidebar',
				'3col' => '3 Columns',
				'2_3col' => '(2 + 3) Columns'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_Layout_Archive', array(
			'label' => esc_html__( '7.3. Archive Display Options', 'robin' ),
			'section' => 'brnhmbx_robin_sectionLayout',
			'settings' => 'brnhmbx_robin_opt_Layout_Archive',
			'type' => 'radio',
			'choices' => array(
				'1col' => '1 Column',
				'1col_sidebar' => '1 Column + Sidebar',
				'2col' => '2 Columns',
				'2col_sidebar' => '2 Columns + Sidebar',
				'1_2col_sidebar' => '(1 + 2) Columns + Sidebar',
				'3col' => '3 Columns',
				'2_3col' => '(2 + 3) Columns'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_explanation_2', array(
			'label' => esc_html__( '7.4. Listing Style Options', 'robin' ),
			'description' => esc_html__( 'If Style Z count is bigger than the number of posts per page, it will be ignored and all the posts will be shown in default style.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionLayout',
			'settings' => 'brnhmbx_robin_explanation_2',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_styleZ_count', array(
			'section' => 'brnhmbx_robin_sectionLayout',
			'description' => esc_html__( 'Number of posts to show in "Style Z":', 'robin' ),
			'settings' => 'brnhmbx_robin_styleZ_count',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_explanation_3', array(
			'label' => esc_html__( '7.5. Listing Style Heights', 'robin' ),
			'description' => esc_html__( 'While using 2 or 3 columned layouts, if you have problems about equalizing the heights of your posts (homepage views), you can set a static size to make their heights equal.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionLayout',
			'settings' => 'brnhmbx_robin_explanation_3',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_minHeight_styleB', array(
			'section' => 'brnhmbx_robin_sectionLayout',
			'description' => esc_html__( 'Minimum height:', 'robin' ),
			'settings' => 'brnhmbx_robin_minHeight_styleB',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_explanation_4', array(
			'label' => esc_html__( '7.6. Sidebar Options', 'robin' ),

			'section' => 'brnhmbx_robin_sectionLayout',
			'settings' => 'brnhmbx_robin_explanation_4',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_SidebarPost_Standard', array(
			'label' => esc_html__( 'Show Sidebar on Standard Posts', 'robin' ),
			'section' => 'brnhmbx_robin_sectionLayout',
			'settings' => 'brnhmbx_robin_sh_SidebarPost_Standard',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_SidebarPost_Gallery', array(
			'label' => esc_html__( 'Show Sidebar on Gallery Posts', 'robin' ),
			'section' => 'brnhmbx_robin_sectionLayout',
			'settings' => 'brnhmbx_robin_sh_SidebarPost_Gallery',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_SidebarPost_Video', array(
			'label' => esc_html__( 'Show Sidebar on Video Posts', 'robin' ),
			'section' => 'brnhmbx_robin_sectionLayout',
			'settings' => 'brnhmbx_robin_sh_SidebarPost_Video',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_SidebarInnerPage', array(
			'label' => esc_html__( 'Show Sidebar on Pages', 'robin' ),
			'section' => 'brnhmbx_robin_sectionLayout',
			'settings' => 'brnhmbx_robin_sh_SidebarInnerPage',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_sh_SidebarShop', array(
			'label' => esc_html__( 'Show Sidebar on Shop Pages', 'robin' ),
			'section' => 'brnhmbx_robin_sectionLayout',
			'settings' => 'brnhmbx_sh_SidebarShop',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_sh_SidebarProduct', array(
			'label' => esc_html__( 'Show Sidebar on Product Pages', 'robin' ),
			'section' => 'brnhmbx_robin_sectionLayout',
			'settings' => 'brnhmbx_sh_SidebarProduct',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_ExtraSidebar_Archive', array(
			'label' => esc_html__( 'Enable "Sidebar - Archive"', 'robin' ),
			'description' => esc_html__( 'Uncheck to use the default sidebar.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionLayout',
			'settings' => 'brnhmbx_robin_ExtraSidebar_Archive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_ExtraSidebar_Page', array(
			'label' => esc_html__( 'Enable "Sidebar - Page"', 'robin' ),
			'description' => esc_html__( 'Uncheck to use the default sidebar.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionLayout',
			'settings' => 'brnhmbx_robin_ExtraSidebar_Page',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_ExtraSidebar_Post', array(
			'label' => esc_html__( 'Enable "Sidebar - Post"', 'robin' ),
			'description' => esc_html__( 'Uncheck to use the default sidebar.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionLayout',
			'settings' => 'brnhmbx_robin_ExtraSidebar_Post',
			'type' => 'checkbox'
		) );
		/* */

		/* Post Format: Standard */
		$wp_customize->add_control( 'brnhmbx_robin_sh_FeaImg_Single_Standard', array(
			'label' => esc_html__( 'Show Featured Image on Post Pages', 'robin' ),
			'section' => 'brnhmbx_robin_sectionPostFormatStandard',
			'settings' => 'brnhmbx_robin_sh_FeaImg_Single_Standard',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_ignoreExcerpt_Standard', array(
			'label' => esc_html__( 'Show full post at Home Page', 'robin' ),
			'section' => 'brnhmbx_robin_sectionPostFormatStandard',
			'settings' => 'brnhmbx_robin_ignoreExcerpt_Standard',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_ignoreExcerpt_Standard_Archive', array(
			'label' => esc_html__( 'Show full post on Archive Pages', 'robin' ),
			'section' => 'brnhmbx_robin_sectionPostFormatStandard',
			'settings' => 'brnhmbx_robin_ignoreExcerpt_Standard_Archive',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_FeaImg_Standard', array(
			'label' => esc_html__( '8.1. Featured Image Options', 'robin' ),

			'section' => 'brnhmbx_robin_sectionPostFormatStandard',
			'settings' => 'brnhmbx_robin_opt_FeaImg_Standard',
			'type' => 'radio',
			'choices' => array(
				'fea' => 'Show featured image',
				'no' => 'No image'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_explanation_13', array(
			'label' => esc_html__( '8.2. Colors', 'robin' ),

			'section' => 'brnhmbx_robin_sectionPostFormatStandard',
			'settings' => 'brnhmbx_robin_explanation_13',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Standard_Background', array(
			'label' => esc_html__( 'Background Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatStandard', 'settings' => 'brnhmbx_robin_color_Standard_Background'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Standard_Header', array(
			'label' => esc_html__( 'Header Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatStandard', 'settings' => 'brnhmbx_robin_color_Standard_Header'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Standard_Content', array(
			'label' => esc_html__( 'Content Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatStandard', 'settings' => 'brnhmbx_robin_color_Standard_Content'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Standard_Link', array(
			'label' => esc_html__( 'Link Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatStandard', 'settings' => 'brnhmbx_robin_color_Standard_Link'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Standard_Link_Hover', array(
			'label' => esc_html__( 'Link Hover Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatStandard', 'settings' => 'brnhmbx_robin_color_Standard_Link_Hover'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Standard_InputBackground', array(
			'label' => esc_html__( 'Input Background Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatStandard', 'settings' => 'brnhmbx_robin_color_Standard_InputBackground'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Standard_InputText', array(
			'label' => esc_html__( 'Input Text Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatStandard', 'settings' => 'brnhmbx_robin_color_Standard_InputText'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Site_RMB', array(
			'label' => esc_html__( 'Post Navigation Button Background Color', 'robin' ), 'description' => esc_html__( 'All post formats use this color.', 'robin' ), 'section' => 'brnhmbx_robin_sectionPostFormatStandard', 'settings' => 'brnhmbx_robin_color_Site_RMB'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Site_RMT', array(
			'label' => esc_html__( 'Post Navigation Button Text Color', 'robin' ), 'description' => esc_html__( 'All post formats use this color.', 'robin' ), 'section' => 'brnhmbx_robin_sectionPostFormatStandard', 'settings' => 'brnhmbx_robin_color_Site_RMT'
		) ) );
		/* */

		/* Post Format: Gallery */
		$wp_customize->add_control( 'brnhmbx_robin_ignoreExcerpt_Gallery', array(
			'label' => esc_html__( 'Show full post at Home Page', 'robin' ),
			'section' => 'brnhmbx_robin_sectionPostFormatGallery',
			'settings' => 'brnhmbx_robin_ignoreExcerpt_Gallery',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_ignoreExcerpt_Gallery_Archive', array(
			'label' => esc_html__( 'Show full post on Archive Pages', 'robin' ),
			'section' => 'brnhmbx_robin_sectionPostFormatGallery',
			'settings' => 'brnhmbx_robin_ignoreExcerpt_Gallery_Archive',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_FeaImg_Gallery', array(
			'label' => esc_html__( '9.1. Featured Image Options', 'robin' ),

			'section' => 'brnhmbx_robin_sectionPostFormatGallery',
			'settings' => 'brnhmbx_robin_opt_FeaImg_Gallery',
			'type' => 'radio',
			'choices' => array(
				'fea' => 'Show featured image',
				'gal' => 'Show gallery image(s)',
				'no' => 'No image'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_GalleryPos_Gallery', array(
			'label' => esc_html__( '9.2. Gallery Position', 'robin' ),
			'description' => esc_html__( 'Choose the gallery position on post page.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionPostFormatGallery',
			'settings' => 'brnhmbx_robin_opt_GalleryPos_Gallery',
			'type' => 'radio',
			'choices' => array(
				'content' => 'Only in Content',
				'iof' => 'Instead of Featured Image',
				'both' => 'Both'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_bxControls', array(
			'label' => esc_html__( '9.3. Gallery Slider Settings', 'robin' ),
			'description' => esc_html__( 'Video sliders will use these settings too but they can not have pager bullets.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionPostFormatGallery',
			'settings' => 'brnhmbx_robin_opt_bxControls',
			'type' => 'radio',
			'choices' => array(
				'arrow' => 'Show Prev/Next Arrows',
				'bullet' => 'Show Pager Bullets',
				'both' => 'Show Both',
				'none' => 'None'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_bxAuto', array(
			'label' => esc_html__( 'Autoplay Slides', 'robin' ),
			'section' => 'brnhmbx_robin_sectionPostFormatGallery',
			'settings' => 'brnhmbx_robin_bxAuto',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_explanation_11', array(
			'label' => esc_html__( '9.4. Colors', 'robin' ),

			'section' => 'brnhmbx_robin_sectionPostFormatGallery',
			'settings' => 'brnhmbx_robin_explanation_11',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_keep_GalleryColors', array(
			'label' => esc_html__( 'Keep the settings below, but use Standard Post colors.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionPostFormatGallery',
			'settings' => 'brnhmbx_robin_keep_GalleryColors',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Gallery_Background', array(
			'label' => esc_html__( 'Background Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatGallery', 'settings' => 'brnhmbx_robin_color_Gallery_Background'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Gallery_Header', array(
			'label' => esc_html__( 'Header Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatGallery', 'settings' => 'brnhmbx_robin_color_Gallery_Header'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Gallery_Content', array(
			'label' => esc_html__( 'Content Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatGallery', 'settings' => 'brnhmbx_robin_color_Gallery_Content'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Gallery_Link', array(
			'label' => esc_html__( 'Link Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatGallery', 'settings' => 'brnhmbx_robin_color_Gallery_Link'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Gallery_Link_Hover', array(
			'label' => esc_html__( 'Link Hover Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatGallery', 'settings' => 'brnhmbx_robin_color_Gallery_Link_Hover'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Gallery_InputBackground', array(
			'label' => esc_html__( 'Input Background Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatGallery', 'settings' => 'brnhmbx_robin_color_Gallery_InputBackground'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Gallery_InputText', array(
			'label' => esc_html__( 'Input Text Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatGallery', 'settings' => 'brnhmbx_robin_color_Gallery_InputText'
		) ) );
		/* */

		/* Post Format: Video */
		$wp_customize->add_control( 'brnhmbx_robin_ignoreExcerpt_Video', array(
			'label' => esc_html__( 'Show full post at Home Page', 'robin' ),
			'section' => 'brnhmbx_robin_sectionPostFormatVideo',
			'settings' => 'brnhmbx_robin_ignoreExcerpt_Video',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_ignoreExcerpt_Video_Archive', array(
			'label' => esc_html__( 'Show full post on Archive Pages', 'robin' ),
			'section' => 'brnhmbx_robin_sectionPostFormatVideo',
			'settings' => 'brnhmbx_robin_ignoreExcerpt_Video_Archive',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_FeaImg_Video', array(
			'label' => esc_html__( '10.1. Featured Image Options', 'robin' ),

			'section' => 'brnhmbx_robin_sectionPostFormatVideo',
			'settings' => 'brnhmbx_robin_opt_FeaImg_Video',
			'type' => 'radio',
			'choices' => array(
				'fea' => 'Show featured image',
				'gal' => 'Show video(s)',
				'no' => 'No image'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_explanation_12', array(
			'label' => esc_html__( '10.2. Colors', 'robin' ),

			'section' => 'brnhmbx_robin_sectionPostFormatVideo',
			'settings' => 'brnhmbx_robin_explanation_12',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_keep_VideoColors', array(
			'label' => esc_html__( 'Keep the settings below, but use Standard Post colors.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionPostFormatVideo',
			'settings' => 'brnhmbx_robin_keep_VideoColors',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Video_Background', array(
			'label' => esc_html__( 'Background Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatVideo', 'settings' => 'brnhmbx_robin_color_Video_Background'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Video_Header', array(
			'label' => esc_html__( 'Header Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatVideo', 'settings' => 'brnhmbx_robin_color_Video_Header'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Video_Content', array(
			'label' => esc_html__( 'Content Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatVideo', 'settings' => 'brnhmbx_robin_color_Video_Content'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Video_Link', array(
			'label' => esc_html__( 'Link Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatVideo', 'settings' => 'brnhmbx_robin_color_Video_Link'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Video_Link_Hover', array(
			'label' => esc_html__( 'Link Hover Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatVideo', 'settings' => 'brnhmbx_robin_color_Video_Link_Hover'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Video_InputBackground', array(
			'label' => esc_html__( 'Input Background Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatVideo', 'settings' => 'brnhmbx_robin_color_Video_InputBackground'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Video_InputText', array(
			'label' => esc_html__( 'Input Text Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionPostFormatVideo', 'settings' => 'brnhmbx_robin_color_Video_InputText'
		) ) );
		/* */

		/* Related Posts */
		$wp_customize->add_control( 'brnhmbx_robin_sh_RelatedPosts', array(
			'label' => esc_html__( 'Show Related Posts', 'robin' ),
			'section' => 'brnhmbx_robin_sectionRP',
			'settings' => 'brnhmbx_robin_sh_RelatedPosts',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_RPDate', array(
			'label' => esc_html__( 'Show Date', 'robin' ),
			'section' => 'brnhmbx_robin_sectionRP',
			'settings' => 'brnhmbx_robin_sh_RPDate',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_RPBase', array(
			'label' => esc_html__( 'Related Term', 'robin' ),
			'section' => 'brnhmbx_robin_sectionRP',

			'settings' => 'brnhmbx_robin_opt_RPBase',
			'type' => 'radio',
			'choices' => array(
				'tag' => 'Tag',
				'category' => 'Category'
			)
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_RP_Header', array(
			'label' => esc_html__( 'Text Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionRP', 'settings' => 'brnhmbx_robin_color_RP_Header'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_RP_Box', array(
			'label' => esc_html__( 'Background Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionRP', 'settings' => 'brnhmbx_robin_color_RP_Box'
		) ) );
		/* */

		/* Footer */
		$wp_customize->add_control( 'brnhmbx_robin_opt_FooterWidgetsWidth', array(
			'label' => esc_html__( '12.1. Container Width', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFooter',

			'settings' => 'brnhmbx_robin_opt_FooterWidgetsWidth',
			'type' => 'radio',
			'choices' => array(
				'boxed' => 'Boxed',
				'full' => 'Fullwidth'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_footerWidgetsCol', array(
			'label' => esc_html__( '12.2. Widget Columns', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFooter',

			'settings' => 'brnhmbx_robin_footerWidgetsCol',
			'type' => 'radio',
			'choices' => array(
				'2col' => '2 Columns',
				'3col' => '3 Columns',
				'4col' => '4 Columns'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_text_Footer', array(
			'label' => esc_html__( '12.3. Copyright Text', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFooter',
			'settings' => 'brnhmbx_robin_text_Footer',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_InstagramShortcode', array(
			'label' => esc_html__( '12.4. Instagram Slider Widget', 'robin' ),
			'description' => esc_html__( 'Instagram Widget Shortcode:', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFooter',
			'settings' => 'brnhmbx_robin_InstagramShortcode',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_InstagramText', array(
			'description' => esc_html__( 'Instagram Widget Button Text:', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFooter',
			'settings' => 'brnhmbx_robin_InstagramText',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Footer', array(
			'label' => esc_html__( 'Show Footer', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFooter',
			'settings' => 'brnhmbx_robin_sh_Footer',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_FooterWidgets', array(
			'label' => esc_html__( 'Show Footer Widgets', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFooter',
			'settings' => 'brnhmbx_robin_sh_FooterWidgets',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_FooterBTT', array(
			'label' => esc_html__( 'Show Back to Top Button', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFooter',
			'settings' => 'brnhmbx_robin_sh_FooterBTT',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_FooterCopyright', array(
			'label' => esc_html__( 'Show Copyright Text', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFooter',
			'settings' => 'brnhmbx_robin_sh_FooterCopyright',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_FooterSocial', array(
			'label' => esc_html__( 'Show Social Accounts', 'robin' ),
			'section' => 'brnhmbx_robin_sectionFooter',
			'settings' => 'brnhmbx_robin_sh_FooterSocial',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_Footer_Background', array(
			'label' => esc_html__( 'Background Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionFooter', 'settings' => 'brnhmbx_robin_color_Footer_Background'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_WF_Title', array(
			'label' => esc_html__( 'Widget Title Color', 'robin' ), 'description' => esc_html__( 'Also used for copyright text.', 'robin' ), 'section' => 'brnhmbx_robin_sectionFooter', 'settings' => 'brnhmbx_robin_color_WF_Title'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_WF_Sep', array(
			'label' => esc_html__( 'Widget Separator Color', 'robin' ), 'description' => esc_html__( 'Also used for social account links.', 'robin' ), 'section' => 'brnhmbx_robin_sectionFooter', 'settings' => 'brnhmbx_robin_color_WF_Sep'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_WF_Link', array(
			'label' => esc_html__( 'Widget Link Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionFooter', 'settings' => 'brnhmbx_robin_color_WF_Link'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_WF_LinkHover', array(
			'label' => esc_html__( 'Link Hover Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionFooter', 'settings' => 'brnhmbx_robin_color_WF_LinkHover'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_WF_Content', array(
			'label' => esc_html__( 'Widget Content Color', 'robin' ), 'description' => esc_html__( 'Used for text widgets, dates etc.', 'robin' ), 'section' => 'brnhmbx_robin_sectionFooter', 'settings' => 'brnhmbx_robin_color_WF_Content'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_WF_InputBackground', array(
			'label' => esc_html__( 'Widget Input Background Color', 'robin' ), 'description' => esc_html__( 'Also used for "Back to Top" button.', 'robin' ), 'section' => 'brnhmbx_robin_sectionFooter', 'settings' => 'brnhmbx_robin_color_WF_InputBackground'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_robin_color_WF_InputText', array(
			'label' => esc_html__( 'Widget Input Text Color', 'robin' ),  'section' => 'brnhmbx_robin_sectionFooter', 'settings' => 'brnhmbx_robin_color_WF_InputText'
		) ) );
		/* */

		/* Show/Hide Elements */
		$wp_customize->add_control( 'brnhmbx_robin_sh_PostComments', array(
			'label' => esc_html__( 'Show Post Comments', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_PostComments',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_PageComments', array(
			'label' => esc_html__( 'Show Page Comments', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_PageComments',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_FilterBar', array(
			'label' => esc_html__( 'Show Filter Bar on Archive Pages', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_FilterBar',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_FilterBar_Word', array(
			'label' => esc_html__( 'Show "Tag /", "Category /", "Author /" etc. on Filter Bar', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_FilterBar_Word',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Date', array(
			'label' => esc_html__( 'Show Date', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_Date',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Date_Home', array(
			'label' => esc_html__( 'Show Date', 'robin' ),
			'description' => esc_html__( 'For indexed views like home, archives etc.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_Date_Home',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_btnComments', array(
			'label' => esc_html__( 'Show Comments Icon', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_btnComments',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_btnComments_Home', array(
			'label' => esc_html__( 'Show Comments Icon', 'robin' ),
			'description' => esc_html__( 'For indexed views like home, archives etc.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_btnComments_Home',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Excerpt', array(
			'label' => esc_html__( 'Show Excerpt', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_Excerpt',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Excerpt_Home', array(
			'label' => esc_html__( 'Show Excerpt', 'robin' ),
			'description' => esc_html__( 'For indexed views like home, archives etc.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_Excerpt_Home',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_TagBar', array(
			'label' => esc_html__( 'Show Tags', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_TagBar',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_TagBar_Home', array(
			'label' => esc_html__( 'Show Tags', 'robin' ),
			'description' => esc_html__( 'For indexed views like home, archives etc.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_TagBar_Home',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_CategoryBar', array(
			'label' => esc_html__( 'Show Categories', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_CategoryBar',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_CategoryBar_Home', array(
			'label' => esc_html__( 'Show Categories', 'robin' ),
			'description' => esc_html__( 'For indexed views like home, archives etc.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_CategoryBar_Home',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_btnReadMore', array(
			'label' => esc_html__( 'Show Read More Button', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_btnReadMore',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Author', array(
			'label' => esc_html__( 'Show Author', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_Author',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_AuthorBox', array(
			'label' => esc_html__( 'Show Author Box on Post Pages', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_AuthorBox',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_SocialBar', array(
			'label' => esc_html__( 'Show Share Icons', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_SocialBar',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_SocialBar_Page', array(
			'label' => esc_html__( 'Show Share Icons on Pages', 'robin' ),
			'description' => esc_html__( 'Only used if "Show Share Icons" is checked.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_SocialBar_Page',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_SocialBar_Facebook', array(
			'label' => esc_html__( 'Show Facebook Share Icon', 'robin' ),
			'description' => esc_html__( 'Only used if "Show Share Icons" is checked.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_SocialBar_Facebook',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_SocialBar_Twitter', array(
			'label' => esc_html__( 'Show Twitter Share Icon', 'robin' ),
			'description' => esc_html__( 'Only used if "Show Share Icons" is checked.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_SocialBar_Twitter',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_SocialBar_Google', array(
			'label' => esc_html__( 'Show Google Share Icon', 'robin' ),
			'description' => esc_html__( 'Only used if "Show Share Icons" is checked.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_sh_SocialBar_Google',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_PageNaviBullet', array(
			'label' => esc_html__( '13.1. Prev/Next Post Button Options', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_opt_PageNaviBullet',
			'type' => 'radio',
			'choices' => array(
				'arrow' => 'Arrow Bullet',
				'image' => 'Image Bullet',
				'none' => 'No Bullet'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_iconAsterisk', array(
			'label' => esc_html__( '13.2. Change - Symbol', 'robin' ),
			'description' => esc_html__( 'Leave blank to hide the icon.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionShowHide',
			'settings' => 'brnhmbx_robin_iconAsterisk',
			'type' => 'text',
			'input_attrs' => array(
				'style' => 'width: 30px;',
			),
		) );
		/* */

		/* Social Accounts */
		$wp_customize->add_control( 'brnhmbx_robin_sh_SocialAccounts', array(
			'label' => esc_html__( 'Show Social Account Icons', 'robin' ),
			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_sh_SocialAccounts',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_Facebook', array(
			'label' => esc_html__( 'Facebook', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_Facebook',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_Twitter', array(
			'label' => esc_html__( 'Twitter', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_Twitter',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_Instagram', array(
			'label' => esc_html__( 'Instagram', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_Instagram',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_Pinterest', array(
			'label' => esc_html__( 'Pinterest', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_Pinterest',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_Google', array(
			'label' => esc_html__( 'Google+', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_Google',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_Tumblr', array(
			'label' => esc_html__( 'Tumblr', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_Tumblr',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_Flickr', array(
			'label' => esc_html__( 'Flickr', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_Flickr',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_Digg', array(
			'label' => esc_html__( 'Digg', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_Digg',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_LinkedIn', array(
			'label' => esc_html__( 'LinkedIn', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_LinkedIn',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_Vimeo', array(
			'label' => esc_html__( 'Vimeo', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_Vimeo',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_YouTube', array(
			'label' => esc_html__( 'YouTube', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_YouTube',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_Behance', array(
			'label' => esc_html__( 'Behance', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_Behance',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_Dribble', array(
			'label' => esc_html__( 'Dribbble', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_Dribble',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_DeviantArt', array(
			'label' => esc_html__( 'DeviantArt', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_DeviantArt',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_Github', array(
			'label' => esc_html__( 'Github', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_Github',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_Bloglovin', array(
			'label' => esc_html__( 'Bloglovin', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_Bloglovin',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_Lastfm', array(
			'label' => esc_html__( 'Last.fm', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_Lastfm',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_SoundCloud', array(
			'label' => esc_html__( 'SoundCloud', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_SoundCloud',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_social_VK', array(
			'label' => esc_html__( 'VK', 'robin' ),

			'section' => 'brnhmbx_robin_sectionSocial',
			'settings' => 'brnhmbx_robin_social_VK',
			'type' => 'text',
		) );
		/* */

		/* Google Maps */
		$wp_customize->add_control( 'brnhmbx_robin_mapPage', array(
			'label' => esc_html__( 'Choose a Page', 'robin' ),
			'section' => 'brnhmbx_robin_sectionGoogleMaps',
			'settings' => 'brnhmbx_robin_mapPage',
			 'type' => 'dropdown-pages',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_coorN', array(
			'label' => esc_html__( 'Coordinate N', 'robin' ),
			'section' => 'brnhmbx_robin_sectionGoogleMaps',
			'settings' => 'brnhmbx_robin_coorN',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_coorE', array(
			'label' => esc_html__( 'Coordinate E', 'robin' ),
			'section' => 'brnhmbx_robin_sectionGoogleMaps',
			'settings' => 'brnhmbx_robin_coorE',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_rng_MapZoom', array(
			'type'        => 'range',
			'section'     => 'brnhmbx_robin_sectionGoogleMaps',
			'label'       => 'Zoom Level',

			'input_attrs' => array(
				'min'   => 5,
				'max'   => 19,
				'step'  => 1
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_mapHeight', array(
			'label' => esc_html__( 'Map Height', 'robin' ),
			'section' => 'brnhmbx_robin_sectionGoogleMaps',
			'settings' => 'brnhmbx_robin_mapHeight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Map', array(
			'label' => esc_html__( 'Show Map', 'robin' ),
			'section' => 'brnhmbx_robin_sectionGoogleMaps',
			'settings' => 'brnhmbx_robin_sh_Map',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_enableMapKey', array(
			'label' => esc_html__( 'Enable Map API Key', 'robin' ),
			'section' => 'brnhmbx_robin_sectionGoogleMaps',
			'settings' => 'brnhmbx_robin_enableMapKey',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_mapAPI', array(
			'label' => esc_html__( 'API Key', 'robin' ),
			'description' => esc_html__( 'Only used if "Enable Map API Key" is checked.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionGoogleMaps',
			'settings' => 'brnhmbx_robin_mapAPI',
			'type' => 'text',
		) );

		function robin_returnMapPageID( $input ) {

			if( is_numeric( $input ) ) {

				return intval( $input );

			}

		}
		/* */

		/* Translation */
		$wp_customize->add_control( 'brnhmbx_robin_IgnorePOT', array(
			'label' => esc_html__( 'Ignore .pot file and use the translations below.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_IgnorePOT',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Lang', array(
			'label' => esc_html__( '16.1. Site Language', 'robin' ),
			'description' => esc_html__( 'Original: "', 'robin' ) . esc_html( get_bloginfo( 'language' ) ) . '"',
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Lang',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_404', array(
			'label' => esc_html__( '16.2. Wording', 'robin' ),
			'description' => esc_html__( 'Original: "Page not found."', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_404',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Nothing', array(
			'description' => esc_html__( 'Original: "Nothing found."', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Nothing',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_SearchResults', array(
			'description' => esc_html__( 'Original: "Search Results"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_SearchResults',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Page', array(
			'description' => esc_html__( 'Original: "Page"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Page',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Tag', array(
			'description' => esc_html__( 'Original: "Tag"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Tag',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Category', array(
			'description' => esc_html__( 'Original: "Category"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Category',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Author', array(
			'description' => esc_html__( 'Original: "Author"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Author',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Archives', array(
			'description' => esc_html__( 'Original: "Archives"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Archives',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Older', array(
			'description' => esc_html__( 'Original: "Older"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Older',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Newer', array(
			'description' => esc_html__( 'Original: "Newer"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Newer',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_By', array(
			'description' => esc_html__( 'Original: "by"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_By',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Keyword', array(
			'description' => esc_html__( 'Original: "Type keyword to search"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Keyword',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_ReadMore', array(
			'description' => esc_html__( 'Original: "Read More"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_ReadMore',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_RelatedPosts', array(
			'description' => esc_html__( 'Original: "Related Posts"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_RelatedPosts',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Comment', array(
			'description' => esc_html__( 'Original: "Comment"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Comment',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_comment', array(
			'description' => esc_html__( 'Original: "comment"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_comment',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Comments', array(
			'description' => esc_html__( 'Original: "Comments"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Comments',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_comments', array(
			'description' => esc_html__( 'Original: "comments"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_comments',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Name', array(
			'description' => esc_html__( 'Original: "Name"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Name',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Email', array(
			'description' => esc_html__( 'Original: "E-mail"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Email',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Website', array(
			'description' => esc_html__( 'Original: "Website"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Website',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_MustBeLogged', array(
			'description' => esc_html__( 'Original: "You must be logged in to post a comment."', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_MustBeLogged',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Logged', array(
			'description' => esc_html__( 'Original: "Logged In"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Logged',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_LogOut', array(
			'description' => esc_html__( 'Original: "Log Out"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_LogOut',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_LeaveReply', array(
			'description' => esc_html__( 'Original: "Leave a Reply"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_LeaveReply',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_CancelReply', array(
			'description' => esc_html__( 'Original: "Cancel Reply"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_CancelReply',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_PostComment', array(
			'description' => esc_html__( 'Original: "Post Comment"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_PostComment',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_At', array(
			'description' => esc_html__( 'Original: "at"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_At',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Reply', array(
			'description' => esc_html__( 'Original: "Reply"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Reply',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Edit', array(
			'description' => esc_html__( 'Original: "Edit"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Edit',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_Awaiting', array(
			'description' => esc_html__( 'Original: "Comment awaiting approval."', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_Awaiting',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_About', array(
			'description' => esc_html__( 'Original: "About"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_About',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_AllByAuthor', array(
			'description' => esc_html__( 'Original: "View All Posts by Author"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_AllByAuthor',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'brnhmbx_robin_tra_AuthorWebsite', array(
			'description' => esc_html__( 'Original: "Visit Author Website"', 'robin' ),
			'section' => 'brnhmbx_robin_sectionTranslation',
			'settings' => 'brnhmbx_robin_tra_AuthorWebsite',
			'type' => 'text',
		) );
		/* */

		/* Banner Management */
		$wp_customize->add_control( 'brnhmbx_robin_opt_ResponsiveBannerHide', array(
			'label' => esc_html__( '19.0. Responsive Options', 'robin' ),

			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_opt_ResponsiveBannerHide',
			'type' => 'radio',
			'choices' => array(
				'always' => 'Always Show',
				'480' => 'Hide at 480px',
				'640' => 'Hide at 640px',
				'800' => 'Hide at 800px',
				'960' => 'Hide at 960px'
			)
		) );
		$wp_customize->add_control( new robin_customTextAreaControl( $wp_customize, 'brnhmbx_robin_text_Banner_1', array(
			'label' => esc_html__( '19.1. Banner 1', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_text_Banner_1',
			'type' => 'text',
		) ) );
		$wp_customize->add_control( new robin_BannerPlacement( $wp_customize, 'brnhmbx_robin_opt_BannerPos_1', array(
			'label' => esc_html__( 'Choose a Position', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBanner',
			'description' => esc_html__( 'Choose the placement for "Banner 1"', 'robin' ),
			'settings' => 'brnhmbx_robin_opt_BannerPos_1'
		) ) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_ResponsiveBanner_1', array(
			'label' => esc_html__( 'Responsive?', 'robin' ),

			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_opt_ResponsiveBanner_1',
			'type' => 'radio',
			'choices' => array(
				'static' => 'Static',
				'responsive' => 'Responsive'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Banner_1_Archive', array(
			'label' => esc_html__( 'Show "Banner 1" on Archive Pages', 'robin' ),

			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_sh_Banner_1_Archive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Banner_1_Post', array(
			'label' => esc_html__( 'Show "Banner 1" on Post Pages', 'robin' ),
			'description' => esc_html__( 'The checkboxes above are only used if "Above Slider" or "Below Slider" is selected.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_sh_Banner_1_Post',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new robin_customTextAreaControl( $wp_customize, 'brnhmbx_robin_text_Banner_2', array(
			'label' => esc_html__( '19.2. Banner 2', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_text_Banner_2',
			'type' => 'text',
		) ) );
		$wp_customize->add_control( new robin_BannerPlacement( $wp_customize, 'brnhmbx_robin_opt_BannerPos_2', array(
			'label' => esc_html__( 'Choose a Position', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBanner',
			'description' => esc_html__( 'Choose the placement for "Banner 2"', 'robin' ),
			'settings' => 'brnhmbx_robin_opt_BannerPos_2'
		) ) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_ResponsiveBanner_2', array(
			'label' => esc_html__( 'Responsive?', 'robin' ),

			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_opt_ResponsiveBanner_2',
			'type' => 'radio',
			'choices' => array(
				'static' => 'Static',
				'responsive' => 'Responsive'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Banner_2_Archive', array(
			'label' => esc_html__( 'Show "Banner 2" on Archive Pages', 'robin' ),

			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_sh_Banner_2_Archive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Banner_2_Post', array(
			'label' => esc_html__( 'Show "Banner 2" on Post Pages', 'robin' ),
			'description' => esc_html__( 'The checkboxes above are only used if "Above Slider" or "Below Slider" is selected.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_sh_Banner_2_Post',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new robin_customTextAreaControl( $wp_customize, 'brnhmbx_robin_text_Banner_3', array(
			'label' => esc_html__( '19.3. Banner 3', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_text_Banner_3',
			'type' => 'text',
		) ) );
		$wp_customize->add_control( new robin_BannerPlacement( $wp_customize, 'brnhmbx_robin_opt_BannerPos_3', array(
			'label' => esc_html__( 'Choose a Position', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBanner',
			'description' => esc_html__( 'Choose the placement for "Banner 3"', 'robin' ),
			'settings' => 'brnhmbx_robin_opt_BannerPos_3'
		) ) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_ResponsiveBanner_3', array(
			'label' => esc_html__( 'Responsive?', 'robin' ),

			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_opt_ResponsiveBanner_3',
			'type' => 'radio',
			'choices' => array(
				'static' => 'Static',
				'responsive' => 'Responsive'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Banner_3_Archive', array(
			'label' => esc_html__( 'Show "Banner 3" on Archive Pages', 'robin' ),

			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_sh_Banner_3_Archive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Banner_3_Post', array(
			'label' => esc_html__( 'Show "Banner 3" on Post Pages', 'robin' ),
			'description' => esc_html__( 'The checkboxes above are only used if "Above Slider" or "Below Slider" is selected.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_sh_Banner_3_Post',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new robin_customTextAreaControl( $wp_customize, 'brnhmbx_robin_text_Banner_4', array(
			'label' => esc_html__( '19.4. Banner 4', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_text_Banner_4',
			'type' => 'text',
		) ) );
		$wp_customize->add_control( new robin_BannerPlacement( $wp_customize, 'brnhmbx_robin_opt_BannerPos_4', array(
			'label' => esc_html__( 'Choose a Position', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBanner',
			'description' => esc_html__( 'Choose the placement for "Banner 4"', 'robin' ),
			'settings' => 'brnhmbx_robin_opt_BannerPos_4'
		) ) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_ResponsiveBanner_4', array(
			'label' => esc_html__( 'Responsive?', 'robin' ),

			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_opt_ResponsiveBanner_4',
			'type' => 'radio',
			'choices' => array(
				'static' => 'Static',
				'responsive' => 'Responsive'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Banner_4_Archive', array(
			'label' => esc_html__( 'Show "Banner 4" on Archive Pages', 'robin' ),

			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_sh_Banner_4_Archive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Banner_4_Post', array(
			'label' => esc_html__( 'Show "Banner 4" on Post Pages', 'robin' ),
			'description' => esc_html__( 'The checkboxes above are only used if "Above Slider" or "Below Slider" is selected.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_sh_Banner_4_Post',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new robin_customTextAreaControl( $wp_customize, 'brnhmbx_robin_text_Banner_5', array(
			'label' => esc_html__( '19.5. Banner 5', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_text_Banner_5',
			'type' => 'text',
		) ) );
		$wp_customize->add_control( new robin_BannerPlacement( $wp_customize, 'brnhmbx_robin_opt_BannerPos_5', array(
			'label' => esc_html__( 'Choose a Position', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBanner',
			'description' => esc_html__( 'Choose the placement for "Banner 5"', 'robin' ),
			'settings' => 'brnhmbx_robin_opt_BannerPos_5'
		) ) );
		$wp_customize->add_control( 'brnhmbx_robin_opt_ResponsiveBanner_5', array(
			'label' => esc_html__( 'Responsive?', 'robin' ),

			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_opt_ResponsiveBanner_5',
			'type' => 'radio',
			'choices' => array(
				'static' => 'Static',
				'responsive' => 'Responsive'
			)
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Banner_5_Archive', array(
			'label' => esc_html__( 'Show "Banner 5" on Archive Pages', 'robin' ),

			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_sh_Banner_5_Archive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'brnhmbx_robin_sh_Banner_5_Post', array(
			'label' => esc_html__( 'Show "Banner 5" on Post Pages', 'robin' ),
			'description' => esc_html__( 'The checkboxes above are only used if "Above Slider" or "Below Slider" is selected.', 'robin' ),
			'section' => 'brnhmbx_robin_sectionBanner',
			'settings' => 'brnhmbx_robin_sh_Banner_5_Post',
			'type' => 'checkbox'
		) );
		/* */

		/* Custom CSS */
		$wp_customize->add_control( new robin_customTextAreaControl( $wp_customize, 'brnhmbx_robin_text_CSS', array(
			'section' => 'brnhmbx_robin_sectionCSS',
			'settings' => 'brnhmbx_robin_text_CSS',
			'type' => 'text',
		) ) );
		/* */

	}
}
add_action( 'customize_register', 'robin_customizeAppearance' );
?>
